@@ -321,6 +321,7 @@ from .formula import * # is constrained by __all__
 from .book import Book, colname #### TODO #### formula also has `colname` (restricted to 256 cols)
 from .sheet import empty_cell
 from .xldate import XLDateError, xldate_as_tuple
+from .xlsx import X12Book
 
 if sys.version.startswith("IronPython"):
     # print >> sys.stderr, "...importing encodings"
@@ -391,9 +392,8 @@ def open_workbook(filename=None,
     if file_contents:
         peek = file_contents[:peeksz]
     else:
-        f = open(filename, "rb")
-        peek = f.read(peeksz)
-        f.close()
+        with open(filename, "rb") as f:
+            peek = f.read(peeksz)
     if peek == b"PK\x03\x04": # a ZIP file
         if file_contents:
             zf = zipfile.ZipFile(timemachine.BYTES_IO(file_contents))
@@ -403,7 +403,7 @@ def open_workbook(filename=None,
         # Workaround for some third party files that use forward slashes and
         # lower case names. We map the expected name in lowercase to the
         # actual filename in the zip container.
-        component_names = dict([(name.replace('\\', '/').lower(), name)
+        component_names = dict([(X12Book.convert_filename(name), name)
                                 for name in zf.namelist()])
 
         if verbosity:
